==> keycloak-session-starter-1.0-sources.jar: digital/nedra/commons/starter/keycloak/session/endpoint/SecurityEndpoint.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session.endpoint;

import static java.util.Objects.nonNull;

import digital.nedra.commons.starter.security.utils.Constants;
import java.util.Optional;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.AuthenticatedPrincipal;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.API_PREFIX + "/uaa")
public class SecurityEndpoint {

  @GetMapping("/me")
  public ResponseEntity<String> me() {
    Object principal = Optional.ofNullable(SecurityContextHolder.getContext())
        .map(SecurityContext::getAuthentication)
        .map(Authentication::getPrincipal)
        .orElse(null);

    if (nonNull(principal)) {
      if (principal instanceof AuthenticatedPrincipal) {
        return ResponseEntity.ok(((AuthenticatedPrincipal) principal).getName());
      } else if (principal instanceof UserDetails) {
        return ResponseEntity.ok(((UserDetails) principal).getUsername());
      }
    }
    return ResponseEntity.notFound().build();
  }
}

==> keycloak-session-starter-2.0.2-sources.jar: digital/nedra/commons/starter/keycloak/session/endpoint/SecurityEndpoint.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session.endpoint;

import static java.util.Objects.nonNull;

import digital.nedra.commons.starter.security.utils.Constants;
import java.util.Optional;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.AuthenticatedPrincipal;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.API_PREFIX + "/uaa")
public class SecurityEndpoint {

  @GetMapping("/me")
  public ResponseEntity<String> me() {
    Object principal = Optional.ofNullable(SecurityContextHolder.getContext())
        .map(SecurityContext::getAuthentication)
        .map(Authentication::getPrincipal)
        .orElse(null);

    if (nonNull(principal)) {
      if (principal instanceof AuthenticatedPrincipal authenticatedPrincipal) {
        return ResponseEntity.ok(authenticatedPrincipal.getName());
      } else if (principal instanceof UserDetails userDetails) {
        return ResponseEntity.ok(userDetails.getUsername());
      }
    }

    return ResponseEntity.notFound().build();
  }
}
